<?php
/**
 * Child Pages Card
 *
 * @package    Child Pages Card
 * @subpackage ChildPagesCardAdmin Management screen
	Copyright (c) 2019- Katsushi Kawamori (email : dodesyoswift312@gmail.com)
	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; version 2 of the License.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

$childpagescardadmin = new ChildPagesCardAdmin();

/** ==================================================
 * Management screen
 */
class ChildPagesCardAdmin {

	/** ==================================================
	 * Construct
	 *
	 * @since 1.00
	 */
	public function __construct() {

		add_action( 'admin_menu', array( $this, 'plugin_menu' ) );
		add_action( 'admin_enqueue_scripts', array( $this, 'load_custom_wp_admin_style' ) );
		add_filter( 'plugin_action_links', array( $this, 'settings_link' ), 10, 2 );

	}

	/** ==================================================
	 * Add a "Settings" link to the plugins page
	 *
	 * @param  array  $links  links array.
	 * @param  string $file   file.
	 * @return array  $links  links array.
	 * @since 1.00
	 */
	public function settings_link( $links, $file ) {
		static $this_plugin;
		if ( empty( $this_plugin ) ) {
			$this_plugin = 'child-pages-card/childpagescard.php';
		}
		if ( $file === $this_plugin ) {
			$links[] = '<a href="' . admin_url( 'options-general.php?page=childpagescard' ) . '">' . __( 'Settings' ) . '</a>';
		}
			return $links;
	}

	/** ==================================================
	 * Settings page
	 *
	 * @since 1.00
	 */
	public function plugin_menu() {
		add_options_page( 'Child Pages Card Options', 'Child Pages Card', 'manage_options', 'childpagescard', array( $this, 'plugin_options' ) );
	}

	/** ==================================================
	 * Add Css and Script
	 *
	 * @since 1.00
	 */
	public function load_custom_wp_admin_style() {
		if ( $this->is_my_plugin_screen() ) {
			wp_enqueue_style( 'wp-color-picker' );
			wp_enqueue_script( 'jquery' );
			wp_enqueue_script( 'childpagescard-admin-js', plugin_dir_url( __DIR__ ) . 'js/jquery.childpagescard.admin.js', array( 'jquery' ), '1.0.0', false );
			wp_enqueue_script( 'colorpicker-admin-js', plugin_dir_url( __DIR__ ) . 'js/jquery.colorpicker.admin.js', array( 'wp-color-picker' ), '1.0.0', false );
		}
	}

	/** ==================================================
	 * For only admin style
	 *
	 * @since 1.00
	 */
	private function is_my_plugin_screen() {
		$screen = get_current_screen();
		if ( is_object( $screen ) && 'settings_page_childpagescard' === $screen->id ) {
			return true;
		} else {
			return false;
		}
	}

	/** ==================================================
	 * Settings page
	 *
	 * @since 1.00
	 */
	public function plugin_options() {

		if ( ! current_user_can( 'manage_options' ) ) {
			wp_die( esc_html__( 'You do not have sufficient permissions to access this page.' ) );
		}

		$this->options_updated();

		$scriptname = admin_url( 'options-general.php?page=childpagescard' );
		$childpagescard_settings = get_option(
			'childpagescard_settings',
			array(
				'pageid' => null,
				'sort' => 'ASC',
				'excerpt' => 500,
				'imgsize' => 100,
				'color' => '#7db4e6',
			)
		);

		$childpagescard_css = get_option( 'childpagescard_css', '.childpagescard_wrap { border: 1px solid #ddd; word-wrap:break-word; max-width: 100%; border-radius: 5px; margin: 30px; } .childpagescard_inner { line-height: 120%; padding: 10px; } .childpagescard_border { padding: 0.25em 0.25em; color: #494949; background: transparent; } .childpagescard_title { font-weight: bold; display: block; } .childpagescard_description { color: #333; }' );

		?>

		<div class="wrap">
		<h2>Child Pages Card</h2>

			<details>
			<summary><strong><?php esc_html_e( 'Various links of this plugin', 'child-pages-card' ); ?></strong></summary>
			<?php $this->credit(); ?>
			</details>

			<div class="wrap">
				<h3><?php esc_html_e( 'Settings' ); ?></h3>	

				<form method="post" action="<?php echo esc_url( $scriptname ); ?>">
				<?php wp_nonce_field( 'cps_set', 'childpagescard_set' ); ?>

				<table border=1 cellspacing="0" cellpadding="5" bordercolor="#000000" style="border-collapse: collapse">
				<tr>
				<td align="center"><strong><?php esc_html_e( 'Attribute', 'child-pages-card' ); ?></strong></td>
				<td align="center"><strong><?php esc_html_e( 'Description' ); ?></strong></td>
				<td align="center"><strong><?php esc_html_e( 'Default value', 'child-pages-card' ); ?></strong></td>
				</tr>

				<tr>
				<td align="center"><code>pageid</code></td>
				<td align="right"><strong>ID <?php esc_html_e( 'Parent Page:' ); ?> </strong></td>
				<td align="center">
				<input type="number" step="1" min="0" name="pageid" value="<?php echo esc_attr( $childpagescard_settings['pageid'] ); ?>" />
				</td>
				</tr>

				<tr>
				<td align="center"><code>sort</code></td>
				<td align="right"><strong><?php esc_html_e( 'Sort Order:' ); ?> </strong></td>
				<td align="center">
				<?php esc_html_e( 'Ascending' ); ?>
				<input type="radio" name="sort" value="ASC" 
				<?php
				if ( 'ASC' === $childpagescard_settings['sort'] ) {
					echo 'checked';}
				?>
				>&nbsp;&nbsp;
				<?php esc_html_e( 'Descending' ); ?>
				<input type="radio" name="sort" value="DESC" 
				<?php
				if ( 'DESC' === $childpagescard_settings['sort'] ) {
					echo 'checked';}
				?>
				>
				</td>
				</tr>

				<tr>
				<td align="center"><code>excerpt</code></td>
				<td align="right"><strong><?php esc_html_e( 'Excerpt' ); ?>: </strong></td>
				<td align="center">
				<input type="range" id="excerpt_bar" style="vertical-align:middle;" step="1" min="0" max="500" name="excerpt" value="<?php echo esc_attr( $childpagescard_settings['excerpt'] ); ?>" /><span id="excerpt_range"></span>
				</td>
				</tr>

				<tr>
				<td align="center"><code>imgsize</code></td>
				<td align="right"><strong><?php esc_html_e( 'Image sizes' ); ?>: </strong></td>
				<td align="center">
				<input type="range" id="imgsize_bar" style="vertical-align:middle;" step="1" min="0" max="200" name="imgsize" value="<?php echo esc_attr( $childpagescard_settings['imgsize'] ); ?>" /><span id="imgsize_range"></span>
				</td>
				</tr>

				<tr>
				<td align="center"><code>color</code></td>
				<td align="right"><strong><?php esc_html_e( 'Color' ); ?>: </strong></td>
				<td align="center">
				<input type="text" class="wpcolor" name="color" value="<?php echo esc_attr( $childpagescard_settings['color'] ); ?>" size="10" />
				</td>
				</tr>

				</table>

				<hr>
				<div><strong>CSS</strong></div>
				<div style="margin: 5px; padding: 5px;">
					<textarea name="customcss" cols="70" rows="6"><?php echo esc_textarea( $childpagescard_css ); ?></textarea>
				</div>

				<p class="submit">
				<?php submit_button( __( 'Save Changes' ), 'large', 'Manageset', false ); ?>
				<?php submit_button( __( 'Default' ), 'large', 'Defaultset', false ); ?>
				</p>

				</form>

			</div>
		</div>

		<?php
	}

	/** ==================================================
	 * Credit
	 *
	 * @since 1.00
	 */
	private function credit() {

		$plugin_name    = null;
		$plugin_ver_num = null;
		$plugin_path    = plugin_dir_path( __DIR__ );
		$plugin_dir     = untrailingslashit( wp_normalize_path( $plugin_path ) );
		$slugs          = explode( '/', $plugin_dir );
		$slug           = end( $slugs );
		$files          = scandir( $plugin_dir );
		foreach ( $files as $file ) {
			if ( '.' === $file || '..' === $file || is_dir( $plugin_path . $file ) ) {
				continue;
			} else {
				$exts = explode( '.', $file );
				$ext  = strtolower( end( $exts ) );
				if ( 'php' === $ext ) {
					$plugin_datas = get_file_data(
						$plugin_path . $file,
						array(
							'name'    => 'Plugin Name',
							'version' => 'Version',
						)
					);
					if ( array_key_exists( 'name', $plugin_datas ) && ! empty( $plugin_datas['name'] ) && array_key_exists( 'version', $plugin_datas ) && ! empty( $plugin_datas['version'] ) ) {
						$plugin_name    = $plugin_datas['name'];
						$plugin_ver_num = $plugin_datas['version'];
						break;
					}
				}
			}
		}
		$plugin_version = __( 'Version:' ) . ' ' . $plugin_ver_num;
		/* translators: FAQ Link & Slug */
		$faq       = sprintf( __( 'https://wordpress.org/plugins/%s/faq', 'child-pages-card' ), $slug );
		$support   = 'https://wordpress.org/support/plugin/' . $slug;
		$review    = 'https://wordpress.org/support/view/plugin-reviews/' . $slug;
		$translate = 'https://translate.wordpress.org/projects/wp-plugins/' . $slug;
		$facebook  = 'https://www.facebook.com/katsushikawamori/';
		$twitter   = 'https://twitter.com/dodesyo312';
		$youtube   = 'https://www.youtube.com/channel/UC5zTLeyROkvZm86OgNRcb_w';
		$donate    = __( 'https://shop.riverforest-wp.info/donate/', 'child-pages-card' );

		?>
		<span style="font-weight: bold;">
		<div>
		<?php echo esc_html( $plugin_version ); ?> | 
		<a style="text-decoration: none;" href="<?php echo esc_url( $faq ); ?>" target="_blank" rel="noopener noreferrer">FAQ</a> | <a style="text-decoration: none;" href="<?php echo esc_url( $support ); ?>" target="_blank" rel="noopener noreferrer">Support Forums</a> | <a style="text-decoration: none;" href="<?php echo esc_url( $review ); ?>" target="_blank" rel="noopener noreferrer">Reviews</a>
		</div>
		<div>
		<a style="text-decoration: none;" href="<?php echo esc_url( $translate ); ?>" target="_blank" rel="noopener noreferrer">
		<?php
		/* translators: Plugin translation link */
		echo esc_html( sprintf( __( 'Translations for %s' ), $plugin_name ) );
		?>
		</a> | <a style="text-decoration: none;" href="<?php echo esc_url( $facebook ); ?>" target="_blank" rel="noopener noreferrer"><span class="dashicons dashicons-facebook"></span></a> | <a style="text-decoration: none;" href="<?php echo esc_url( $twitter ); ?>" target="_blank" rel="noopener noreferrer"><span class="dashicons dashicons-twitter"></span></a> | <a style="text-decoration: none;" href="<?php echo esc_url( $youtube ); ?>" target="_blank" rel="noopener noreferrer"><span class="dashicons dashicons-video-alt3"></span></a>
		</div>
		</span>

		<div style="width: 250px; height: 180px; margin: 5px; padding: 5px; border: #CCC 2px solid;">
		<h3><?php esc_html_e( 'Please make a donation if you like my work or would like to further the development of this plugin.', 'child-pages-card' ); ?></h3>
		<div style="text-align: right; margin: 5px; padding: 5px;"><span style="padding: 3px; color: #ffffff; background-color: #008000">Plugin Author</span> <span style="font-weight: bold;">Katsushi Kawamori</span></div>
		<button type="button" style="margin: 5px; padding: 5px;" onclick="window.open('<?php echo esc_url( $donate ); ?>')"><?php esc_html_e( 'Donate to this plugin &#187;' ); ?></button>
		</div>

		<?php

	}

	/** ==================================================
	 * Update wp_options table.
	 *
	 * @since 1.00
	 */
	private function options_updated() {

		if ( isset( $_POST['Manageset'] ) && ! empty( $_POST['Manageset'] ) ) {
			if ( check_admin_referer( 'cps_set', 'childpagescard_set' ) ) {
				if ( isset( $_POST['pageid'] ) ) {
					if ( empty( $_POST['pageid'] ) ) {
						$childpagescard_settings['pageid'] = null;
					} else {
						$childpagescard_settings['pageid'] = intval( $_POST['pageid'] );
					}
				}
				if ( isset( $_POST['sort'] ) && ! empty( $_POST['sort'] ) ) {
					$childpagescard_settings['sort'] = sanitize_text_field( wp_unslash( $_POST['sort'] ) );
				}
				if ( isset( $_POST['excerpt'] ) ) {
					$childpagescard_settings['excerpt'] = intval( $_POST['excerpt'] );
				}
				if ( isset( $_POST['imgsize'] ) ) {
					$childpagescard_settings['imgsize'] = intval( $_POST['imgsize'] );
				}
				if ( isset( $_POST['color'] ) && ! empty( $_POST['color'] ) ) {
					$childpagescard_settings['color'] = sanitize_text_field( wp_unslash( $_POST['color'] ) );
				}
				if ( ! empty( $_POST['customcss'] ) ) {
					$childpagescard_css = sanitize_text_field( wp_unslash( $_POST['customcss'] ) );
				}
				update_option( 'childpagescard_settings', $childpagescard_settings );
				update_option( 'childpagescard_css', $childpagescard_css );
				echo '<div class="notice notice-success is-dismissible"><ul><li>' . esc_html__( 'Settings' ) . ' --> ' . esc_html__( 'Settings saved.' ) . '</li></ul></div>';
			}
		}

		if ( isset( $_POST['Defaultset'] ) && ! empty( $_POST['Defaultset'] ) ) {
			if ( check_admin_referer( 'cps_set', 'childpagescard_set' ) ) {
				delete_option( 'childpagescard_settings' );
				delete_option( 'childpagescard_css' );
				echo '<div class="notice notice-success is-dismissible"><ul><li>' . esc_html__( 'Settings' ) . ' --> ' . esc_html__( 'Default' ) . '</li></ul></div>';
			}
		}

	}

}


